# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from gradientai import GradientAI, AsyncGradientAI
from tests.utils import assert_matches_type
from gradientai.types.agents import (
    EvaluationDatasetCreateResponse,
    EvaluationDatasetCreateFileUploadPresignedURLsResponse,
)

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestEvaluationDatasets:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip()
    @parametrize
    def test_method_create(self, client: GradientAI) -> None:
        evaluation_dataset = client.agents.evaluation_datasets.create()
        assert_matches_type(EvaluationDatasetCreateResponse, evaluation_dataset, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_method_create_with_all_params(self, client: GradientAI) -> None:
        evaluation_dataset = client.agents.evaluation_datasets.create(
            file_upload_dataset={
                "original_file_name": "original_file_name",
                "size_in_bytes": "size_in_bytes",
                "stored_object_key": "stored_object_key",
            },
            name="name",
        )
        assert_matches_type(EvaluationDatasetCreateResponse, evaluation_dataset, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_create(self, client: GradientAI) -> None:
        response = client.agents.evaluation_datasets.with_raw_response.create()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        evaluation_dataset = response.parse()
        assert_matches_type(EvaluationDatasetCreateResponse, evaluation_dataset, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_create(self, client: GradientAI) -> None:
        with client.agents.evaluation_datasets.with_streaming_response.create() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            evaluation_dataset = response.parse()
            assert_matches_type(EvaluationDatasetCreateResponse, evaluation_dataset, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_method_create_file_upload_presigned_urls(self, client: GradientAI) -> None:
        evaluation_dataset = client.agents.evaluation_datasets.create_file_upload_presigned_urls()
        assert_matches_type(
            EvaluationDatasetCreateFileUploadPresignedURLsResponse, evaluation_dataset, path=["response"]
        )

    @pytest.mark.skip()
    @parametrize
    def test_method_create_file_upload_presigned_urls_with_all_params(self, client: GradientAI) -> None:
        evaluation_dataset = client.agents.evaluation_datasets.create_file_upload_presigned_urls(
            files=[
                {
                    "file_name": "file_name",
                    "file_size": "file_size",
                }
            ],
        )
        assert_matches_type(
            EvaluationDatasetCreateFileUploadPresignedURLsResponse, evaluation_dataset, path=["response"]
        )

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_create_file_upload_presigned_urls(self, client: GradientAI) -> None:
        response = client.agents.evaluation_datasets.with_raw_response.create_file_upload_presigned_urls()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        evaluation_dataset = response.parse()
        assert_matches_type(
            EvaluationDatasetCreateFileUploadPresignedURLsResponse, evaluation_dataset, path=["response"]
        )

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_create_file_upload_presigned_urls(self, client: GradientAI) -> None:
        with client.agents.evaluation_datasets.with_streaming_response.create_file_upload_presigned_urls() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            evaluation_dataset = response.parse()
            assert_matches_type(
                EvaluationDatasetCreateFileUploadPresignedURLsResponse, evaluation_dataset, path=["response"]
            )

        assert cast(Any, response.is_closed) is True


class TestAsyncEvaluationDatasets:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip()
    @parametrize
    async def test_method_create(self, async_client: AsyncGradientAI) -> None:
        evaluation_dataset = await async_client.agents.evaluation_datasets.create()
        assert_matches_type(EvaluationDatasetCreateResponse, evaluation_dataset, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_create_with_all_params(self, async_client: AsyncGradientAI) -> None:
        evaluation_dataset = await async_client.agents.evaluation_datasets.create(
            file_upload_dataset={
                "original_file_name": "original_file_name",
                "size_in_bytes": "size_in_bytes",
                "stored_object_key": "stored_object_key",
            },
            name="name",
        )
        assert_matches_type(EvaluationDatasetCreateResponse, evaluation_dataset, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_create(self, async_client: AsyncGradientAI) -> None:
        response = await async_client.agents.evaluation_datasets.with_raw_response.create()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        evaluation_dataset = await response.parse()
        assert_matches_type(EvaluationDatasetCreateResponse, evaluation_dataset, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_create(self, async_client: AsyncGradientAI) -> None:
        async with async_client.agents.evaluation_datasets.with_streaming_response.create() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            evaluation_dataset = await response.parse()
            assert_matches_type(EvaluationDatasetCreateResponse, evaluation_dataset, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_method_create_file_upload_presigned_urls(self, async_client: AsyncGradientAI) -> None:
        evaluation_dataset = await async_client.agents.evaluation_datasets.create_file_upload_presigned_urls()
        assert_matches_type(
            EvaluationDatasetCreateFileUploadPresignedURLsResponse, evaluation_dataset, path=["response"]
        )

    @pytest.mark.skip()
    @parametrize
    async def test_method_create_file_upload_presigned_urls_with_all_params(
        self, async_client: AsyncGradientAI
    ) -> None:
        evaluation_dataset = await async_client.agents.evaluation_datasets.create_file_upload_presigned_urls(
            files=[
                {
                    "file_name": "file_name",
                    "file_size": "file_size",
                }
            ],
        )
        assert_matches_type(
            EvaluationDatasetCreateFileUploadPresignedURLsResponse, evaluation_dataset, path=["response"]
        )

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_create_file_upload_presigned_urls(self, async_client: AsyncGradientAI) -> None:
        response = await async_client.agents.evaluation_datasets.with_raw_response.create_file_upload_presigned_urls()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        evaluation_dataset = await response.parse()
        assert_matches_type(
            EvaluationDatasetCreateFileUploadPresignedURLsResponse, evaluation_dataset, path=["response"]
        )

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_create_file_upload_presigned_urls(self, async_client: AsyncGradientAI) -> None:
        async with (
            async_client.agents.evaluation_datasets.with_streaming_response.create_file_upload_presigned_urls()
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            evaluation_dataset = await response.parse()
            assert_matches_type(
                EvaluationDatasetCreateFileUploadPresignedURLsResponse, evaluation_dataset, path=["response"]
            )

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ...._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from ...._utils import maybe_transform, async_maybe_transform
from ...._compat import cached_property
from ...._resource import SyncAPIResource, AsyncAPIResource
from ...._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...._base_client import make_request_options
from ....types.model_providers.anthropic import (
    key_list_params,
    key_create_params,
    key_update_params,
    key_list_agents_params,
)
from ....types.model_providers.anthropic.key_list_response import KeyListResponse
from ....types.model_providers.anthropic.key_create_response import KeyCreateResponse
from ....types.model_providers.anthropic.key_delete_response import KeyDeleteResponse
from ....types.model_providers.anthropic.key_update_response import KeyUpdateResponse
from ....types.model_providers.anthropic.key_retrieve_response import KeyRetrieveResponse
from ....types.model_providers.anthropic.key_list_agents_response import KeyListAgentsResponse

__all__ = ["KeysResource", "AsyncKeysResource"]


class KeysResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> KeysResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/digitalocean/gradientai-python#accessing-raw-response-data-eg-headers
        """
        return KeysResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> KeysResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/digitalocean/gradientai-python#with_streaming_response
        """
        return KeysResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        api_key: str | NotGiven = NOT_GIVEN,
        name: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> KeyCreateResponse:
        """
        To create an Anthropic API key, send a POST request to
        `/v2/gen-ai/anthropic/keys`.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/v2/gen-ai/anthropic/keys"
            if self._client._base_url_overridden
            else "https://api.digitalocean.com/v2/gen-ai/anthropic/keys",
            body=maybe_transform(
                {
                    "api_key": api_key,
                    "name": name,
                },
                key_create_params.KeyCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=KeyCreateResponse,
        )

    def retrieve(
        self,
        api_key_uuid: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> KeyRetrieveResponse:
        """
        To retrieve details of an Anthropic API key, send a GET request to
        `/v2/gen-ai/anthropic/keys/{api_key_uuid}`.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not api_key_uuid:
            raise ValueError(f"Expected a non-empty value for `api_key_uuid` but received {api_key_uuid!r}")
        return self._get(
            f"/v2/gen-ai/anthropic/keys/{api_key_uuid}"
            if self._client._base_url_overridden
            else f"https://api.digitalocean.com/v2/gen-ai/anthropic/keys/{api_key_uuid}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=KeyRetrieveResponse,
        )

    def update(
        self,
        path_api_key_uuid: str,
        *,
        api_key: str | NotGiven = NOT_GIVEN,
        body_api_key_uuid: str | NotGiven = NOT_GIVEN,
        name: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> KeyUpdateResponse:
        """
        To update an Anthropic API key, send a PUT request to
        `/v2/gen-ai/anthropic/keys/{api_key_uuid}`.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not path_api_key_uuid:
            raise ValueError(f"Expected a non-empty value for `path_api_key_uuid` but received {path_api_key_uuid!r}")
        return self._put(
            f"/v2/gen-ai/anthropic/keys/{path_api_key_uuid}"
            if self._client._base_url_overridden
            else f"https://api.digitalocean.com/v2/gen-ai/anthropic/keys/{path_api_key_uuid}",
            body=maybe_transform(
                {
                    "api_key": api_key,
                    "body_api_key_uuid": body_api_key_uuid,
                    "name": name,
                },
                key_update_params.KeyUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=KeyUpdateResponse,
        )

    def list(
        self,
        *,
        page: int | NotGiven = NOT_GIVEN,
        per_page: int | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> KeyListResponse:
        """
        To list all Anthropic API keys, send a GET request to
        `/v2/gen-ai/anthropic/keys`.

        Args:
          page: page number.

          per_page: items per page.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get(
            "/v2/gen-ai/anthropic/keys"
            if self._client._base_url_overridden
            else "https://api.digitalocean.com/v2/gen-ai/anthropic/keys",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "page": page,
                        "per_page": per_page,
                    },
                    key_list_params.KeyListParams,
                ),
            ),
            cast_to=KeyListResponse,
        )

    def delete(
        self,
        api_key_uuid: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> KeyDeleteResponse:
        """
        To delete an Anthropic API key, send a DELETE request to
        `/v2/gen-ai/anthropic/keys/{api_key_uuid}`.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not api_key_uuid:
            raise ValueError(f"Expected a non-empty value for `api_key_uuid` but received {api_key_uuid!r}")
        return self._delete(
            f"/v2/gen-ai/anthropic/keys/{api_key_uuid}"
            if self._client._base_url_overridden
            else f"https://api.digitalocean.com/v2/gen-ai/anthropic/keys/{api_key_uuid}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=KeyDeleteResponse,
        )

    def list_agents(
        self,
        uuid: str,
        *,
        page: int | NotGiven = NOT_GIVEN,
        per_page: int | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> KeyListAgentsResponse:
        """
        List Agents by Anthropic Key.

        Args:
          page: page number.

          per_page: items per page.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not uuid:
            raise ValueError(f"Expected a non-empty value for `uuid` but received {uuid!r}")
        return self._get(
            f"/v2/gen-ai/anthropic/keys/{uuid}/agents"
            if self._client._base_url_overridden
            else f"https://api.digitalocean.com/v2/gen-ai/anthropic/keys/{uuid}/agents",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "page": page,
                        "per_page": per_page,
                    },
                    key_list_agents_params.KeyListAgentsParams,
                ),
            ),
            cast_to=KeyListAgentsResponse,
        )


class AsyncKeysResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncKeysResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/digitalocean/gradientai-python#accessing-raw-response-data-eg-headers
        """
        return AsyncKeysResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncKeysResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/digitalocean/gradientai-python#with_streaming_response
        """
        return AsyncKeysResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        api_key: str | NotGiven = NOT_GIVEN,
        name: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> KeyCreateResponse:
        """
        To create an Anthropic API key, send a POST request to
        `/v2/gen-ai/anthropic/keys`.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/v2/gen-ai/anthropic/keys"
            if self._client._base_url_overridden
            else "https://api.digitalocean.com/v2/gen-ai/anthropic/keys",
            body=await async_maybe_transform(
                {
                    "api_key": api_key,
                    "name": name,
                },
                key_create_params.KeyCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=KeyCreateResponse,
        )

    async def retrieve(
        self,
        api_key_uuid: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> KeyRetrieveResponse:
        """
        To retrieve details of an Anthropic API key, send a GET request to
        `/v2/gen-ai/anthropic/keys/{api_key_uuid}`.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not api_key_uuid:
            raise ValueError(f"Expected a non-empty value for `api_key_uuid` but received {api_key_uuid!r}")
        return await self._get(
            f"/v2/gen-ai/anthropic/keys/{api_key_uuid}"
            if self._client._base_url_overridden
            else f"https://api.digitalocean.com/v2/gen-ai/anthropic/keys/{api_key_uuid}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=KeyRetrieveResponse,
        )

    async def update(
        self,
        path_api_key_uuid: str,
        *,
        api_key: str | NotGiven = NOT_GIVEN,
        body_api_key_uuid: str | NotGiven = NOT_GIVEN,
        name: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> KeyUpdateResponse:
        """
        To update an Anthropic API key, send a PUT request to
        `/v2/gen-ai/anthropic/keys/{api_key_uuid}`.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not path_api_key_uuid:
            raise ValueError(f"Expected a non-empty value for `path_api_key_uuid` but received {path_api_key_uuid!r}")
        return await self._put(
            f"/v2/gen-ai/anthropic/keys/{path_api_key_uuid}"
            if self._client._base_url_overridden
            else f"https://api.digitalocean.com/v2/gen-ai/anthropic/keys/{path_api_key_uuid}",
            body=await async_maybe_transform(
                {
                    "api_key": api_key,
                    "body_api_key_uuid": body_api_key_uuid,
                    "name": name,
                },
                key_update_params.KeyUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=KeyUpdateResponse,
        )

    async def list(
        self,
        *,
        page: int | NotGiven = NOT_GIVEN,
        per_page: int | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> KeyListResponse:
        """
        To list all Anthropic API keys, send a GET request to
        `/v2/gen-ai/anthropic/keys`.

        Args:
          page: page number.

          per_page: items per page.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._get(
            "/v2/gen-ai/anthropic/keys"
            if self._client._base_url_overridden
            else "https://api.digitalocean.com/v2/gen-ai/anthropic/keys",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "page": page,
                        "per_page": per_page,
                    },
                    key_list_params.KeyListParams,
                ),
            ),
            cast_to=KeyListResponse,
        )

    async def delete(
        self,
        api_key_uuid: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> KeyDeleteResponse:
        """
        To delete an Anthropic API key, send a DELETE request to
        `/v2/gen-ai/anthropic/keys/{api_key_uuid}`.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not api_key_uuid:
            raise ValueError(f"Expected a non-empty value for `api_key_uuid` but received {api_key_uuid!r}")
        return await self._delete(
            f"/v2/gen-ai/anthropic/keys/{api_key_uuid}"
            if self._client._base_url_overridden
            else f"https://api.digitalocean.com/v2/gen-ai/anthropic/keys/{api_key_uuid}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=KeyDeleteResponse,
        )

    async def list_agents(
        self,
        uuid: str,
        *,
        page: int | NotGiven = NOT_GIVEN,
        per_page: int | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> KeyListAgentsResponse:
        """
        List Agents by Anthropic Key.

        Args:
          page: page number.

          per_page: items per page.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not uuid:
            raise ValueError(f"Expected a non-empty value for `uuid` but received {uuid!r}")
        return await self._get(
            f"/v2/gen-ai/anthropic/keys/{uuid}/agents"
            if self._client._base_url_overridden
            else f"https://api.digitalocean.com/v2/gen-ai/anthropic/keys/{uuid}/agents",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "page": page,
                        "per_page": per_page,
                    },
                    key_list_agents_params.KeyListAgentsParams,
                ),
            ),
            cast_to=KeyListAgentsResponse,
        )


class KeysResourceWithRawResponse:
    def __init__(self, keys: KeysResource) -> None:
        self._keys = keys

        self.create = to_raw_response_wrapper(
            keys.create,
        )
        self.retrieve = to_raw_response_wrapper(
            keys.retrieve,
        )
        self.update = to_raw_response_wrapper(
            keys.update,
        )
        self.list = to_raw_response_wrapper(
            keys.list,
        )
        self.delete = to_raw_response_wrapper(
            keys.delete,
        )
        self.list_agents = to_raw_response_wrapper(
            keys.list_agents,
        )


class AsyncKeysResourceWithRawResponse:
    def __init__(self, keys: AsyncKeysResource) -> None:
        self._keys = keys

        self.create = async_to_raw_response_wrapper(
            keys.create,
        )
        self.retrieve = async_to_raw_response_wrapper(
            keys.retrieve,
        )
        self.update = async_to_raw_response_wrapper(
            keys.update,
        )
        self.list = async_to_raw_response_wrapper(
            keys.list,
        )
        self.delete = async_to_raw_response_wrapper(
            keys.delete,
        )
        self.list_agents = async_to_raw_response_wrapper(
            keys.list_agents,
        )


class KeysResourceWithStreamingResponse:
    def __init__(self, keys: KeysResource) -> None:
        self._keys = keys

        self.create = to_streamed_response_wrapper(
            keys.create,
        )
        self.retrieve = to_streamed_response_wrapper(
            keys.retrieve,
        )
        self.update = to_streamed_response_wrapper(
            keys.update,
        )
        self.list = to_streamed_response_wrapper(
            keys.list,
        )
        self.delete = to_streamed_response_wrapper(
            keys.delete,
        )
        self.list_agents = to_streamed_response_wrapper(
            keys.list_agents,
        )


class AsyncKeysResourceWithStreamingResponse:
    def __init__(self, keys: AsyncKeysResource) -> None:
        self._keys = keys

        self.create = async_to_streamed_response_wrapper(
            keys.create,
        )
        self.retrieve = async_to_streamed_response_wrapper(
            keys.retrieve,
        )
        self.update = async_to_streamed_response_wrapper(
            keys.update,
        )
        self.list = async_to_streamed_response_wrapper(
            keys.list,
        )
        self.delete = async_to_streamed_response_wrapper(
            keys.delete,
        )
        self.list_agents = async_to_streamed_response_wrapper(
            keys.list_agents,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from .._models import BaseModel
from .api_knowledge_base import APIKnowledgeBase

__all__ = ["KnowledgeBaseCreateResponse"]


class KnowledgeBaseCreateResponse(BaseModel):
    knowledge_base: Optional[APIKnowledgeBase] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List

import httpx

from ..._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from ..._utils import maybe_transform, async_maybe_transform
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._base_client import make_request_options
from ...types.agents import (
    evaluation_test_case_create_params,
    evaluation_test_case_update_params,
    evaluation_test_case_retrieve_params,
    evaluation_test_case_list_evaluation_runs_params,
)
from ...types.agents.api_star_metric_param import APIStarMetricParam
from ...types.agents.evaluation_test_case_list_response import EvaluationTestCaseListResponse
from ...types.agents.evaluation_test_case_create_response import EvaluationTestCaseCreateResponse
from ...types.agents.evaluation_test_case_update_response import EvaluationTestCaseUpdateResponse
from ...types.agents.evaluation_test_case_retrieve_response import EvaluationTestCaseRetrieveResponse
from ...types.agents.evaluation_test_case_list_evaluation_runs_response import (
    EvaluationTestCaseListEvaluationRunsResponse,
)

__all__ = ["EvaluationTestCasesResource", "AsyncEvaluationTestCasesResource"]


class EvaluationTestCasesResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> EvaluationTestCasesResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/digitalocean/gradientai-python#accessing-raw-response-data-eg-headers
        """
        return EvaluationTestCasesResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> EvaluationTestCasesResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/digitalocean/gradientai-python#with_streaming_response
        """
        return EvaluationTestCasesResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        dataset_uuid: str | NotGiven = NOT_GIVEN,
        description: str | NotGiven = NOT_GIVEN,
        metrics: List[str] | NotGiven = NOT_GIVEN,
        name: str | NotGiven = NOT_GIVEN,
        star_metric: APIStarMetricParam | NotGiven = NOT_GIVEN,
        workspace_uuid: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> EvaluationTestCaseCreateResponse:
        """
        To create an evaluation test-case send a POST request to
        `/v2/gen-ai/evaluation_test_cases`.

        Args:
          dataset_uuid: Dataset against which the test‑case is executed.

          description: Description of the test case.

          metrics: Full metric list to use for evaluation test case.

          name: Name of the test case.

          workspace_uuid: The workspace uuid.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/v2/gen-ai/evaluation_test_cases"
            if self._client._base_url_overridden
            else "https://api.digitalocean.com/v2/gen-ai/evaluation_test_cases",
            body=maybe_transform(
                {
                    "dataset_uuid": dataset_uuid,
                    "description": description,
                    "metrics": metrics,
                    "name": name,
                    "star_metric": star_metric,
                    "workspace_uuid": workspace_uuid,
                },
                evaluation_test_case_create_params.EvaluationTestCaseCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=EvaluationTestCaseCreateResponse,
        )

    def retrieve(
        self,
        test_case_uuid: str,
        *,
        evaluation_test_case_version: int | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> EvaluationTestCaseRetrieveResponse:
        """
        To retrive information about an existing evaluation test case, send a GET
        request to `/v2/gen-ai/evaluation_test_case/{test_case_uuid}`.

        Args:
          evaluation_test_case_version: Version of the test case.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not test_case_uuid:
            raise ValueError(f"Expected a non-empty value for `test_case_uuid` but received {test_case_uuid!r}")
        return self._get(
            f"/v2/gen-ai/evaluation_test_cases/{test_case_uuid}"
            if self._client._base_url_overridden
            else f"https://api.digitalocean.com/v2/gen-ai/evaluation_test_cases/{test_case_uuid}",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {"evaluation_test_case_version": evaluation_test_case_version},
                    evaluation_test_case_retrieve_params.EvaluationTestCaseRetrieveParams,
                ),
            ),
            cast_to=EvaluationTestCaseRetrieveResponse,
        )

    def update(
        self,
        path_test_case_uuid: str,
        *,
        dataset_uuid: str | NotGiven = NOT_GIVEN,
        description: str | NotGiven = NOT_GIVEN,
        metrics: evaluation_test_case_update_params.Metrics | NotGiven = NOT_GIVEN,
        name: str | NotGiven = NOT_GIVEN,
        star_metric: APIStarMetricParam | NotGiven = NOT_GIVEN,
        body_test_case_uuid: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> EvaluationTestCaseUpdateResponse:
        """
        To update an evaluation test-case send a POST request to
        `/v2/gen-ai/evaluation_test_cases/{test_case_uuid}`.

        Args:
          dataset_uuid: Dataset against which the test‑case is executed.

          description: Description of the test case.

          name: Name of the test case.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not path_test_case_uuid:
            raise ValueError(
                f"Expected a non-empty value for `path_test_case_uuid` but received {path_test_case_uuid!r}"
            )
        return self._post(
            f"/v2/gen-ai/evaluation_test_cases/{path_test_case_uuid}"
            if self._client._base_url_overridden
            else f"https://api.digitalocean.com/v2/gen-ai/evaluation_test_cases/{path_test_case_uuid}",
            body=maybe_transform(
                {
                    "dataset_uuid": dataset_uuid,
                    "description": description,
                    "metrics": metrics,
                    "name": name,
                    "star_metric": star_metric,
                    "body_test_case_uuid": body_test_case_uuid,
                },
                evaluation_test_case_update_params.EvaluationTestCaseUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=EvaluationTestCaseUpdateResponse,
        )

    def list(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> EvaluationTestCaseListResponse:
        """
        To list all evaluation test cases, send a GET request to
        `/v2/gen-ai/evaluation_test_cases`.
        """
        return self._get(
            "/v2/gen-ai/evaluation_test_cases"
            if self._client._base_url_overridden
            else "https://api.digitalocean.com/v2/gen-ai/evaluation_test_cases",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=EvaluationTestCaseListResponse,
        )

    def list_evaluation_runs(
        self,
        evaluation_test_case_uuid: str,
        *,
        evaluation_test_case_version: int | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> EvaluationTestCaseListEvaluationRunsResponse:
        """
        To list all evaluation runs by test case, send a GET request to
        `/v2/gen-ai/evaluation_test_cases/{evaluation_test_case_uuid}/evaluation_runs`.

        Args:
          evaluation_test_case_version: Version of the test case.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not evaluation_test_case_uuid:
            raise ValueError(
                f"Expected a non-empty value for `evaluation_test_case_uuid` but received {evaluation_test_case_uuid!r}"
            )
        return self._get(
            f"/v2/gen-ai/evaluation_test_cases/{evaluation_test_case_uuid}/evaluation_runs"
            if self._client._base_url_overridden
            else f"https://api.digitalocean.com/v2/gen-ai/evaluation_test_cases/{evaluation_test_case_uuid}/evaluation_runs",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {"evaluation_test_case_version": evaluation_test_case_version},
                    evaluation_test_case_list_evaluation_runs_params.EvaluationTestCaseListEvaluationRunsParams,
                ),
            ),
            cast_to=EvaluationTestCaseListEvaluationRunsResponse,
        )


class AsyncEvaluationTestCasesResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncEvaluationTestCasesResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/digitalocean/gradientai-python#accessing-raw-response-data-eg-headers
        """
        return AsyncEvaluationTestCasesResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncEvaluationTestCasesResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/digitalocean/gradientai-python#with_streaming_response
        """
        return AsyncEvaluationTestCasesResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        dataset_uuid: str | NotGiven = NOT_GIVEN,
        description: str | NotGiven = NOT_GIVEN,
        metrics: List[str] | NotGiven = NOT_GIVEN,
        name: str | NotGiven = NOT_GIVEN,
        star_metric: APIStarMetricParam | NotGiven = NOT_GIVEN,
        workspace_uuid: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> EvaluationTestCaseCreateResponse:
        """
        To create an evaluation test-case send a POST request to
        `/v2/gen-ai/evaluation_test_cases`.

        Args:
          dataset_uuid: Dataset against which the test‑case is executed.

          description: Description of the test case.

          metrics: Full metric list to use for evaluation test case.

          name: Name of the test case.

          workspace_uuid: The workspace uuid.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/v2/gen-ai/evaluation_test_cases"
            if self._client._base_url_overridden
            else "https://api.digitalocean.com/v2/gen-ai/evaluation_test_cases",
            body=await async_maybe_transform(
                {
                    "dataset_uuid": dataset_uuid,
                    "description": description,
                    "metrics": metrics,
                    "name": name,
                    "star_metric": star_metric,
                    "workspace_uuid": workspace_uuid,
                },
                evaluation_test_case_create_params.EvaluationTestCaseCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=EvaluationTestCaseCreateResponse,
        )

    async def retrieve(
        self,
        test_case_uuid: str,
        *,
        evaluation_test_case_version: int | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> EvaluationTestCaseRetrieveResponse:
        """
        To retrive information about an existing evaluation test case, send a GET
        request to `/v2/gen-ai/evaluation_test_case/{test_case_uuid}`.

        Args:
          evaluation_test_case_version: Version of the test case.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not test_case_uuid:
            raise ValueError(f"Expected a non-empty value for `test_case_uuid` but received {test_case_uuid!r}")
        return await self._get(
            f"/v2/gen-ai/evaluation_test_cases/{test_case_uuid}"
            if self._client._base_url_overridden
            else f"https://api.digitalocean.com/v2/gen-ai/evaluation_test_cases/{test_case_uuid}",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {"evaluation_test_case_version": evaluation_test_case_version},
                    evaluation_test_case_retrieve_params.EvaluationTestCaseRetrieveParams,
                ),
            ),
            cast_to=EvaluationTestCaseRetrieveResponse,
        )

    async def update(
        self,
        path_test_case_uuid: str,
        *,
        dataset_uuid: str | NotGiven = NOT_GIVEN,
        description: str | NotGiven = NOT_GIVEN,
        metrics: evaluation_test_case_update_params.Metrics | NotGiven = NOT_GIVEN,
        name: str | NotGiven = NOT_GIVEN,
        star_metric: APIStarMetricParam | NotGiven = NOT_GIVEN,
        body_test_case_uuid: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> EvaluationTestCaseUpdateResponse:
        """
        To update an evaluation test-case send a POST request to
        `/v2/gen-ai/evaluation_test_cases/{test_case_uuid}`.

        Args:
          dataset_uuid: Dataset against which the test‑case is executed.

          description: Description of the test case.

          name: Name of the test case.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not path_test_case_uuid:
            raise ValueError(
                f"Expected a non-empty value for `path_test_case_uuid` but received {path_test_case_uuid!r}"
            )
        return await self._post(
            f"/v2/gen-ai/evaluation_test_cases/{path_test_case_uuid}"
            if self._client._base_url_overridden
            else f"https://api.digitalocean.com/v2/gen-ai/evaluation_test_cases/{path_test_case_uuid}",
            body=await async_maybe_transform(
                {
                    "dataset_uuid": dataset_uuid,
                    "description": description,
                    "metrics": metrics,
                    "name": name,
                    "star_metric": star_metric,
                    "body_test_case_uuid": body_test_case_uuid,
                },
                evaluation_test_case_update_params.EvaluationTestCaseUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=EvaluationTestCaseUpdateResponse,
        )

    async def list(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> EvaluationTestCaseListResponse:
        """
        To list all evaluation test cases, send a GET request to
        `/v2/gen-ai/evaluation_test_cases`.
        """
        return await self._get(
            "/v2/gen-ai/evaluation_test_cases"
            if self._client._base_url_overridden
            else "https://api.digitalocean.com/v2/gen-ai/evaluation_test_cases",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=EvaluationTestCaseListResponse,
        )

    async def list_evaluation_runs(
        self,
        evaluation_test_case_uuid: str,
        *,
        evaluation_test_case_version: int | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> EvaluationTestCaseListEvaluationRunsResponse:
        """
        To list all evaluation runs by test case, send a GET request to
        `/v2/gen-ai/evaluation_test_cases/{evaluation_test_case_uuid}/evaluation_runs`.

        Args:
          evaluation_test_case_version: Version of the test case.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not evaluation_test_case_uuid:
            raise ValueError(
                f"Expected a non-empty value for `evaluation_test_case_uuid` but received {evaluation_test_case_uuid!r}"
            )
        return await self._get(
            f"/v2/gen-ai/evaluation_test_cases/{evaluation_test_case_uuid}/evaluation_runs"
            if self._client._base_url_overridden
            else f"https://api.digitalocean.com/v2/gen-ai/evaluation_test_cases/{evaluation_test_case_uuid}/evaluation_runs",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {"evaluation_test_case_version": evaluation_test_case_version},
                    evaluation_test_case_list_evaluation_runs_params.EvaluationTestCaseListEvaluationRunsParams,
                ),
            ),
            cast_to=EvaluationTestCaseListEvaluationRunsResponse,
        )


class EvaluationTestCasesResourceWithRawResponse:
    def __init__(self, evaluation_test_cases: EvaluationTestCasesResource) -> None:
        self._evaluation_test_cases = evaluation_test_cases

        self.create = to_raw_response_wrapper(
            evaluation_test_cases.create,
        )
        self.retrieve = to_raw_response_wrapper(
            evaluation_test_cases.retrieve,
        )
        self.update = to_raw_response_wrapper(
            evaluation_test_cases.update,
        )
        self.list = to_raw_response_wrapper(
            evaluation_test_cases.list,
        )
        self.list_evaluation_runs = to_raw_response_wrapper(
            evaluation_test_cases.list_evaluation_runs,
        )


class AsyncEvaluationTestCasesResourceWithRawResponse:
    def __init__(self, evaluation_test_cases: AsyncEvaluationTestCasesResource) -> None:
        self._evaluation_test_cases = evaluation_test_cases

        self.create = async_to_raw_response_wrapper(
            evaluation_test_cases.create,
        )
        self.retrieve = async_to_raw_response_wrapper(
            evaluation_test_cases.retrieve,
        )
        self.update = async_to_raw_response_wrapper(
            evaluation_test_cases.update,
        )
        self.list = async_to_raw_response_wrapper(
            evaluation_test_cases.list,
        )
        self.list_evaluation_runs = async_to_raw_response_wrapper(
            evaluation_test_cases.list_evaluation_runs,
        )


class EvaluationTestCasesResourceWithStreamingResponse:
    def __init__(self, evaluation_test_cases: EvaluationTestCasesResource) -> None:
        self._evaluation_test_cases = evaluation_test_cases

        self.create = to_streamed_response_wrapper(
            evaluation_test_cases.create,
        )
        self.retrieve = to_streamed_response_wrapper(
            evaluation_test_cases.retrieve,
        )
        self.update = to_streamed_response_wrapper(
            evaluation_test_cases.update,
        )
        self.list = to_streamed_response_wrapper(
            evaluation_test_cases.list,
        )
        self.list_evaluation_runs = to_streamed_response_wrapper(
            evaluation_test_cases.list_evaluation_runs,
        )


class AsyncEvaluationTestCasesResourceWithStreamingResponse:
    def __init__(self, evaluation_test_cases: AsyncEvaluationTestCasesResource) -> None:
        self._evaluation_test_cases = evaluation_test_cases

        self.create = async_to_streamed_response_wrapper(
            evaluation_test_cases.create,
        )
        self.retrieve = async_to_streamed_response_wrapper(
            evaluation_test_cases.retrieve,
        )
        self.update = async_to_streamed_response_wrapper(
            evaluation_test_cases.update,
        )
        self.list = async_to_streamed_response_wrapper(
            evaluation_test_cases.list,
        )
        self.list_evaluation_runs = async_to_streamed_response_wrapper(
            evaluation_test_cases.list_evaluation_runs,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from ..._models import BaseModel
from .api_evaluation_test_case import APIEvaluationTestCase

__all__ = ["EvaluationTestCaseListResponse"]


class EvaluationTestCaseListResponse(BaseModel):
    evaluation_test_cases: Optional[List[APIEvaluationTestCase]] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from ..._models import BaseModel
from .api_evaluation_run import APIEvaluationRun

__all__ = ["EvaluationRunRetrieveResponse"]


class EvaluationRunRetrieveResponse(BaseModel):
    evaluation_run: Optional[APIEvaluationRun] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from ..._models import BaseModel

__all__ = ["APIFileUploadDataSource"]


class APIFileUploadDataSource(BaseModel):
    original_file_name: Optional[str] = None

    size_in_bytes: Optional[str] = None

    stored_object_key: Optional[str] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List, Optional

from ...._models import BaseModel
from ...shared.api_meta import APIMeta
from ...shared.api_links import APILinks

__all__ = ["KeyListAgentsResponse"]


class KeyListAgentsResponse(BaseModel):
    agents: Optional[List["APIAgent"]] = None

    links: Optional[APILinks] = None

    meta: Optional[APIMeta] = None


from ...api_agent import APIAgent



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from gradientai import GradientAI, AsyncGradientAI
from tests.utils import assert_matches_type
from gradientai.types.agents import (
    RouteAddResponse,
    RouteViewResponse,
    RouteDeleteResponse,
    RouteUpdateResponse,
)

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestRoutes:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip()
    @parametrize
    def test_method_update(self, client: GradientAI) -> None:
        route = client.agents.routes.update(
            path_child_agent_uuid="child_agent_uuid",
            path_parent_agent_uuid="parent_agent_uuid",
        )
        assert_matches_type(RouteUpdateResponse, route, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_method_update_with_all_params(self, client: GradientAI) -> None:
        route = client.agents.routes.update(
            path_child_agent_uuid="child_agent_uuid",
            path_parent_agent_uuid="parent_agent_uuid",
            body_child_agent_uuid="child_agent_uuid",
            if_case="if_case",
            body_parent_agent_uuid="parent_agent_uuid",
            route_name="route_name",
            uuid="uuid",
        )
        assert_matches_type(RouteUpdateResponse, route, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_update(self, client: GradientAI) -> None:
        response = client.agents.routes.with_raw_response.update(
            path_child_agent_uuid="child_agent_uuid",
            path_parent_agent_uuid="parent_agent_uuid",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        route = response.parse()
        assert_matches_type(RouteUpdateResponse, route, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_update(self, client: GradientAI) -> None:
        with client.agents.routes.with_streaming_response.update(
            path_child_agent_uuid="child_agent_uuid",
            path_parent_agent_uuid="parent_agent_uuid",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            route = response.parse()
            assert_matches_type(RouteUpdateResponse, route, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_path_params_update(self, client: GradientAI) -> None:
        with pytest.raises(
            ValueError, match=r"Expected a non-empty value for `path_parent_agent_uuid` but received ''"
        ):
            client.agents.routes.with_raw_response.update(
                path_child_agent_uuid="child_agent_uuid",
                path_parent_agent_uuid="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `path_child_agent_uuid` but received ''"):
            client.agents.routes.with_raw_response.update(
                path_child_agent_uuid="",
                path_parent_agent_uuid="parent_agent_uuid",
            )

    @pytest.mark.skip()
    @parametrize
    def test_method_delete(self, client: GradientAI) -> None:
        route = client.agents.routes.delete(
            child_agent_uuid="child_agent_uuid",
            parent_agent_uuid="parent_agent_uuid",
        )
        assert_matches_type(RouteDeleteResponse, route, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_delete(self, client: GradientAI) -> None:
        response = client.agents.routes.with_raw_response.delete(
            child_agent_uuid="child_agent_uuid",
            parent_agent_uuid="parent_agent_uuid",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        route = response.parse()
        assert_matches_type(RouteDeleteResponse, route, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_delete(self, client: GradientAI) -> None:
        with client.agents.routes.with_streaming_response.delete(
            child_agent_uuid="child_agent_uuid",
            parent_agent_uuid="parent_agent_uuid",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            route = response.parse()
            assert_matches_type(RouteDeleteResponse, route, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_path_params_delete(self, client: GradientAI) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `parent_agent_uuid` but received ''"):
            client.agents.routes.with_raw_response.delete(
                child_agent_uuid="child_agent_uuid",
                parent_agent_uuid="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `child_agent_uuid` but received ''"):
            client.agents.routes.with_raw_response.delete(
                child_agent_uuid="",
                parent_agent_uuid="parent_agent_uuid",
            )

    @pytest.mark.skip()
    @parametrize
    def test_method_add(self, client: GradientAI) -> None:
        route = client.agents.routes.add(
            path_child_agent_uuid="child_agent_uuid",
            path_parent_agent_uuid="parent_agent_uuid",
        )
        assert_matches_type(RouteAddResponse, route, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_method_add_with_all_params(self, client: GradientAI) -> None:
        route = client.agents.routes.add(
            path_child_agent_uuid="child_agent_uuid",
            path_parent_agent_uuid="parent_agent_uuid",
            body_child_agent_uuid="child_agent_uuid",
            if_case="if_case",
            body_parent_agent_uuid="parent_agent_uuid",
            route_name="route_name",
        )
        assert_matches_type(RouteAddResponse, route, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_add(self, client: GradientAI) -> None:
        response = client.agents.routes.with_raw_response.add(
            path_child_agent_uuid="child_agent_uuid",
            path_parent_agent_uuid="parent_agent_uuid",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        route = response.parse()
        assert_matches_type(RouteAddResponse, route, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_add(self, client: GradientAI) -> None:
        with client.agents.routes.with_streaming_response.add(
            path_child_agent_uuid="child_agent_uuid",
            path_parent_agent_uuid="parent_agent_uuid",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            route = response.parse()
            assert_matches_type(RouteAddResponse, route, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_path_params_add(self, client: GradientAI) -> None:
        with pytest.raises(
            ValueError, match=r"Expected a non-empty value for `path_parent_agent_uuid` but received ''"
        ):
            client.agents.routes.with_raw_response.add(
                path_child_agent_uuid="child_agent_uuid",
                path_parent_agent_uuid="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `path_child_agent_uuid` but received ''"):
            client.agents.routes.with_raw_response.add(
                path_child_agent_uuid="",
                path_parent_agent_uuid="parent_agent_uuid",
            )

    @pytest.mark.skip()
    @parametrize
    def test_method_view(self, client: GradientAI) -> None:
        route = client.agents.routes.view(
            "uuid",
        )
        assert_matches_type(RouteViewResponse, route, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_view(self, client: GradientAI) -> None:
        response = client.agents.routes.with_raw_response.view(
            "uuid",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        route = response.parse()
        assert_matches_type(RouteViewResponse, route, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_view(self, client: GradientAI) -> None:
        with client.agents.routes.with_streaming_response.view(
            "uuid",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            route = response.parse()
            assert_matches_type(RouteViewResponse, route, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_path_params_view(self, client: GradientAI) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `uuid` but received ''"):
            client.agents.routes.with_raw_response.view(
                "",
            )


class TestAsyncRoutes:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip()
    @parametrize
    async def test_method_update(self, async_client: AsyncGradientAI) -> None:
        route = await async_client.agents.routes.update(
            path_child_agent_uuid="child_agent_uuid",
            path_parent_agent_uuid="parent_agent_uuid",
        )
        assert_matches_type(RouteUpdateResponse, route, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_update_with_all_params(self, async_client: AsyncGradientAI) -> None:
        route = await async_client.agents.routes.update(
            path_child_agent_uuid="child_agent_uuid",
            path_parent_agent_uuid="parent_agent_uuid",
            body_child_agent_uuid="child_agent_uuid",
            if_case="if_case",
            body_parent_agent_uuid="parent_agent_uuid",
            route_name="route_name",
            uuid="uuid",
        )
        assert_matches_type(RouteUpdateResponse, route, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_update(self, async_client: AsyncGradientAI) -> None:
        response = await async_client.agents.routes.with_raw_response.update(
            path_child_agent_uuid="child_agent_uuid",
            path_parent_agent_uuid="parent_agent_uuid",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        route = await response.parse()
        assert_matches_type(RouteUpdateResponse, route, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_update(self, async_client: AsyncGradientAI) -> None:
        async with async_client.agents.routes.with_streaming_response.update(
            path_child_agent_uuid="child_agent_uuid",
            path_parent_agent_uuid="parent_agent_uuid",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            route = await response.parse()
            assert_matches_type(RouteUpdateResponse, route, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_path_params_update(self, async_client: AsyncGradientAI) -> None:
        with pytest.raises(
            ValueError, match=r"Expected a non-empty value for `path_parent_agent_uuid` but received ''"
        ):
            await async_client.agents.routes.with_raw_response.update(
                path_child_agent_uuid="child_agent_uuid",
                path_parent_agent_uuid="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `path_child_agent_uuid` but received ''"):
            await async_client.agents.routes.with_raw_response.update(
                path_child_agent_uuid="",
                path_parent_agent_uuid="parent_agent_uuid",
            )

    @pytest.mark.skip()
    @parametrize
    async def test_method_delete(self, async_client: AsyncGradientAI) -> None:
        route = await async_client.agents.routes.delete(
            child_agent_uuid="child_agent_uuid",
            parent_agent_uuid="parent_agent_uuid",
        )
        assert_matches_type(RouteDeleteResponse, route, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_delete(self, async_client: AsyncGradientAI) -> None:
        response = await async_client.agents.routes.with_raw_response.delete(
            child_agent_uuid="child_agent_uuid",
            parent_agent_uuid="parent_agent_uuid",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        route = await response.parse()
        assert_matches_type(RouteDeleteResponse, route, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_delete(self, async_client: AsyncGradientAI) -> None:
        async with async_client.agents.routes.with_streaming_response.delete(
            child_agent_uuid="child_agent_uuid",
            parent_agent_uuid="parent_agent_uuid",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            route = await response.parse()
            assert_matches_type(RouteDeleteResponse, route, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_path_params_delete(self, async_client: AsyncGradientAI) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `parent_agent_uuid` but received ''"):
            await async_client.agents.routes.with_raw_response.delete(
                child_agent_uuid="child_agent_uuid",
                parent_agent_uuid="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `child_agent_uuid` but received ''"):
            await async_client.agents.routes.with_raw_response.delete(
                child_agent_uuid="",
                parent_agent_uuid="parent_agent_uuid",
            )

    @pytest.mark.skip()
    @parametrize
    async def test_method_add(self, async_client: AsyncGradientAI) -> None:
        route = await async_client.agents.routes.add(
            path_child_agent_uuid="child_agent_uuid",
            path_parent_agent_uuid="parent_agent_uuid",
        )
        assert_matches_type(RouteAddResponse, route, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_add_with_all_params(self, async_client: AsyncGradientAI) -> None:
        route = await async_client.agents.routes.add(
            path_child_agent_uuid="child_agent_uuid",
            path_parent_agent_uuid="parent_agent_uuid",
            body_child_agent_uuid="child_agent_uuid",
            if_case="if_case",
            body_parent_agent_uuid="parent_agent_uuid",
            route_name="route_name",
        )
        assert_matches_type(RouteAddResponse, route, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_add(self, async_client: AsyncGradientAI) -> None:
        response = await async_client.agents.routes.with_raw_response.add(
            path_child_agent_uuid="child_agent_uuid",
            path_parent_agent_uuid="parent_agent_uuid",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        route = await response.parse()
        assert_matches_type(RouteAddResponse, route, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_add(self, async_client: AsyncGradientAI) -> None:
        async with async_client.agents.routes.with_streaming_response.add(
            path_child_agent_uuid="child_agent_uuid",
            path_parent_agent_uuid="parent_agent_uuid",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            route = await response.parse()
            assert_matches_type(RouteAddResponse, route, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_path_params_add(self, async_client: AsyncGradientAI) -> None:
        with pytest.raises(
            ValueError, match=r"Expected a non-empty value for `path_parent_agent_uuid` but received ''"
        ):
            await async_client.agents.routes.with_raw_response.add(
                path_child_agent_uuid="child_agent_uuid",
                path_parent_agent_uuid="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `path_child_agent_uuid` but received ''"):
            await async_client.agents.routes.with_raw_response.add(
                path_child_agent_uuid="",
                path_parent_agent_uuid="parent_agent_uuid",
            )

    @pytest.mark.skip()
    @parametrize
    async def test_method_view(self, async_client: AsyncGradientAI) -> None:
        route = await async_client.agents.routes.view(
            "uuid",
        )
        assert_matches_type(RouteViewResponse, route, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_view(self, async_client: AsyncGradientAI) -> None:
        response = await async_client.agents.routes.with_raw_response.view(
            "uuid",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        route = await response.parse()
        assert_matches_type(RouteViewResponse, route, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_view(self, async_client: AsyncGradientAI) -> None:
        async with async_client.agents.routes.with_streaming_response.view(
            "uuid",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            route = await response.parse()
            assert_matches_type(RouteViewResponse, route, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_path_params_view(self, async_client: AsyncGradientAI) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `uuid` but received ''"):
            await async_client.agents.routes.with_raw_response.view(
                "",
            )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime

from .._models import BaseModel
from .knowledge_bases.api_indexing_job import APIIndexingJob

__all__ = ["APIKnowledgeBase"]


class APIKnowledgeBase(BaseModel):
    added_to_agent_at: Optional[datetime] = None

    created_at: Optional[datetime] = None

    database_id: Optional[str] = None

    embedding_model_uuid: Optional[str] = None

    is_public: Optional[bool] = None

    last_indexing_job: Optional[APIIndexingJob] = None

    name: Optional[str] = None

    project_id: Optional[str] = None

    region: Optional[str] = None

    tags: Optional[List[str]] = None

    updated_at: Optional[datetime] = None

    user_id: Optional[str] = None

    uuid: Optional[str] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from datetime import datetime
from typing_extensions import Literal

from ..._models import BaseModel

__all__ = ["APIIndexedDataSource"]


class APIIndexedDataSource(BaseModel):
    completed_at: Optional[datetime] = None

    data_source_uuid: Optional[str] = None

    error_details: Optional[str] = None

    error_msg: Optional[str] = None

    failed_item_count: Optional[str] = None

    indexed_file_count: Optional[str] = None

    indexed_item_count: Optional[str] = None

    removed_item_count: Optional[str] = None

    skipped_item_count: Optional[str] = None

    started_at: Optional[datetime] = None

    status: Optional[
        Literal[
            "DATA_SOURCE_STATUS_UNKNOWN",
            "DATA_SOURCE_STATUS_IN_PROGRESS",
            "DATA_SOURCE_STATUS_UPDATED",
            "DATA_SOURCE_STATUS_PARTIALLY_UPDATED",
            "DATA_SOURCE_STATUS_NOT_UPDATED",
            "DATA_SOURCE_STATUS_FAILED",
        ]
    ] = None

    total_bytes: Optional[str] = None

    total_bytes_indexed: Optional[str] = None

    total_file_count: Optional[str] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Annotated, TypedDict

from ..._utils import PropertyInfo

__all__ = ["FunctionCreateParams"]


class FunctionCreateParams(TypedDict, total=False):
    body_agent_uuid: Annotated[str, PropertyInfo(alias="agent_uuid")]

    description: str

    faas_name: str

    faas_namespace: str

    function_name: str

    input_schema: object

    output_schema: object



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from ..._models import BaseModel

__all__ = ["EvaluationDatasetCreateResponse"]


class EvaluationDatasetCreateResponse(BaseModel):
    evaluation_dataset_uuid: Optional[str] = None
    """Evaluation dataset uuid."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional

from ..._models import BaseModel

__all__ = ["FunctionCreateResponse"]


class FunctionCreateResponse(BaseModel):
    agent: Optional["APIAgent"] = None


from ..api_agent import APIAgent



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List

import httpx

from ..._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from ..._utils import maybe_transform, async_maybe_transform
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._base_client import make_request_options
from ...types.agents import evaluation_run_create_params
from ...types.agents.evaluation_run_create_response import EvaluationRunCreateResponse
from ...types.agents.evaluation_run_retrieve_response import EvaluationRunRetrieveResponse
from ...types.agents.evaluation_run_list_results_response import EvaluationRunListResultsResponse
from ...types.agents.evaluation_run_retrieve_results_response import EvaluationRunRetrieveResultsResponse

__all__ = ["EvaluationRunsResource", "AsyncEvaluationRunsResource"]


class EvaluationRunsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> EvaluationRunsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/digitalocean/gradientai-python#accessing-raw-response-data-eg-headers
        """
        return EvaluationRunsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> EvaluationRunsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/digitalocean/gradientai-python#with_streaming_response
        """
        return EvaluationRunsResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        agent_uuids: List[str] | NotGiven = NOT_GIVEN,
        run_name: str | NotGiven = NOT_GIVEN,
        test_case_uuid: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> EvaluationRunCreateResponse:
        """
        To run an evaluation test case, send a POST request to
        `/v2/gen-ai/evaluation_runs`.

        Args:
          agent_uuids: Agent UUIDs to run the test case against.

          run_name: The name of the run.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/v2/gen-ai/evaluation_runs"
            if self._client._base_url_overridden
            else "https://api.digitalocean.com/v2/gen-ai/evaluation_runs",
            body=maybe_transform(
                {
                    "agent_uuids": agent_uuids,
                    "run_name": run_name,
                    "test_case_uuid": test_case_uuid,
                },
                evaluation_run_create_params.EvaluationRunCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=EvaluationRunCreateResponse,
        )

    def retrieve(
        self,
        evaluation_run_uuid: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> EvaluationRunRetrieveResponse:
        """
        To retrive information about an existing evaluation run, send a GET request to
        `/v2/gen-ai/evaluation_runs/{evaluation_run_uuid}`.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not evaluation_run_uuid:
            raise ValueError(
                f"Expected a non-empty value for `evaluation_run_uuid` but received {evaluation_run_uuid!r}"
            )
        return self._get(
            f"/v2/gen-ai/evaluation_runs/{evaluation_run_uuid}"
            if self._client._base_url_overridden
            else f"https://api.digitalocean.com/v2/gen-ai/evaluation_runs/{evaluation_run_uuid}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=EvaluationRunRetrieveResponse,
        )

    def list_results(
        self,
        evaluation_run_uuid: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> EvaluationRunListResultsResponse:
        """
        To retrieve results of an evaluation run, send a GET request to
        `/v2/gen-ai/evaluation_runs/{evaluation_run_uuid}/results`.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not evaluation_run_uuid:
            raise ValueError(
                f"Expected a non-empty value for `evaluation_run_uuid` but received {evaluation_run_uuid!r}"
            )
        return self._get(
            f"/v2/gen-ai/evaluation_runs/{evaluation_run_uuid}/results"
            if self._client._base_url_overridden
            else f"https://api.digitalocean.com/v2/gen-ai/evaluation_runs/{evaluation_run_uuid}/results",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=EvaluationRunListResultsResponse,
        )

    def retrieve_results(
        self,
        prompt_id: int,
        *,
        evaluation_run_uuid: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> EvaluationRunRetrieveResultsResponse:
        """
        To retrieve results of an evaluation run, send a GET request to
        `/v2/gen-ai/evaluation_runs/{evaluation_run_uuid}/results/{prompt_id}`.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not evaluation_run_uuid:
            raise ValueError(
                f"Expected a non-empty value for `evaluation_run_uuid` but received {evaluation_run_uuid!r}"
            )
        return self._get(
            f"/v2/gen-ai/evaluation_runs/{evaluation_run_uuid}/results/{prompt_id}"
            if self._client._base_url_overridden
            else f"https://api.digitalocean.com/v2/gen-ai/evaluation_runs/{evaluation_run_uuid}/results/{prompt_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=EvaluationRunRetrieveResultsResponse,
        )


class AsyncEvaluationRunsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncEvaluationRunsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/digitalocean/gradientai-python#accessing-raw-response-data-eg-headers
        """
        return AsyncEvaluationRunsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncEvaluationRunsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/digitalocean/gradientai-python#with_streaming_response
        """
        return AsyncEvaluationRunsResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        agent_uuids: List[str] | NotGiven = NOT_GIVEN,
        run_name: str | NotGiven = NOT_GIVEN,
        test_case_uuid: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> EvaluationRunCreateResponse:
        """
        To run an evaluation test case, send a POST request to
        `/v2/gen-ai/evaluation_runs`.

        Args:
          agent_uuids: Agent UUIDs to run the test case against.

          run_name: The name of the run.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/v2/gen-ai/evaluation_runs"
            if self._client._base_url_overridden
            else "https://api.digitalocean.com/v2/gen-ai/evaluation_runs",
            body=await async_maybe_transform(
                {
                    "agent_uuids": agent_uuids,
                    "run_name": run_name,
                    "test_case_uuid": test_case_uuid,
                },
                evaluation_run_create_params.EvaluationRunCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=EvaluationRunCreateResponse,
        )

    async def retrieve(
        self,
        evaluation_run_uuid: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> EvaluationRunRetrieveResponse:
        """
        To retrive information about an existing evaluation run, send a GET request to
        `/v2/gen-ai/evaluation_runs/{evaluation_run_uuid}`.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not evaluation_run_uuid:
            raise ValueError(
                f"Expected a non-empty value for `evaluation_run_uuid` but received {evaluation_run_uuid!r}"
            )
        return await self._get(
            f"/v2/gen-ai/evaluation_runs/{evaluation_run_uuid}"
            if self._client._base_url_overridden
            else f"https://api.digitalocean.com/v2/gen-ai/evaluation_runs/{evaluation_run_uuid}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=EvaluationRunRetrieveResponse,
        )

    async def list_results(
        self,
        evaluation_run_uuid: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> EvaluationRunListResultsResponse:
        """
        To retrieve results of an evaluation run, send a GET request to
        `/v2/gen-ai/evaluation_runs/{evaluation_run_uuid}/results`.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not evaluation_run_uuid:
            raise ValueError(
                f"Expected a non-empty value for `evaluation_run_uuid` but received {evaluation_run_uuid!r}"
            )
        return await self._get(
            f"/v2/gen-ai/evaluation_runs/{evaluation_run_uuid}/results"
            if self._client._base_url_overridden
            else f"https://api.digitalocean.com/v2/gen-ai/evaluation_runs/{evaluation_run_uuid}/results",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=EvaluationRunListResultsResponse,
        )

    async def retrieve_results(
        self,
        prompt_id: int,
        *,
        evaluation_run_uuid: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> EvaluationRunRetrieveResultsResponse:
        """
        To retrieve results of an evaluation run, send a GET request to
        `/v2/gen-ai/evaluation_runs/{evaluation_run_uuid}/results/{prompt_id}`.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not evaluation_run_uuid:
            raise ValueError(
                f"Expected a non-empty value for `evaluation_run_uuid` but received {evaluation_run_uuid!r}"
            )
        return await self._get(
            f"/v2/gen-ai/evaluation_runs/{evaluation_run_uuid}/results/{prompt_id}"
            if self._client._base_url_overridden
            else f"https://api.digitalocean.com/v2/gen-ai/evaluation_runs/{evaluation_run_uuid}/results/{prompt_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=EvaluationRunRetrieveResultsResponse,
        )


class EvaluationRunsResourceWithRawResponse:
    def __init__(self, evaluation_runs: EvaluationRunsResource) -> None:
        self._evaluation_runs = evaluation_runs

        self.create = to_raw_response_wrapper(
            evaluation_runs.create,
        )
        self.retrieve = to_raw_response_wrapper(
            evaluation_runs.retrieve,
        )
        self.list_results = to_raw_response_wrapper(
            evaluation_runs.list_results,
        )
        self.retrieve_results = to_raw_response_wrapper(
            evaluation_runs.retrieve_results,
        )


class AsyncEvaluationRunsResourceWithRawResponse:
    def __init__(self, evaluation_runs: AsyncEvaluationRunsResource) -> None:
        self._evaluation_runs = evaluation_runs

        self.create = async_to_raw_response_wrapper(
            evaluation_runs.create,
        )
        self.retrieve = async_to_raw_response_wrapper(
            evaluation_runs.retrieve,
        )
        self.list_results = async_to_raw_response_wrapper(
            evaluation_runs.list_results,
        )
        self.retrieve_results = async_to_raw_response_wrapper(
            evaluation_runs.retrieve_results,
        )


class EvaluationRunsResourceWithStreamingResponse:
    def __init__(self, evaluation_runs: EvaluationRunsResource) -> None:
        self._evaluation_runs = evaluation_runs

        self.create = to_streamed_response_wrapper(
            evaluation_runs.create,
        )
        self.retrieve = to_streamed_response_wrapper(
            evaluation_runs.retrieve,
        )
        self.list_results = to_streamed_response_wrapper(
            evaluation_runs.list_results,
        )
        self.retrieve_results = to_streamed_response_wrapper(
            evaluation_runs.retrieve_results,
        )


class AsyncEvaluationRunsResourceWithStreamingResponse:
    def __init__(self, evaluation_runs: AsyncEvaluationRunsResource) -> None:
        self._evaluation_runs = evaluation_runs

        self.create = async_to_streamed_response_wrapper(
            evaluation_runs.create,
        )
        self.retrieve = async_to_streamed_response_wrapper(
            evaluation_runs.retrieve,
        )
        self.list_results = async_to_streamed_response_wrapper(
            evaluation_runs.list_results,
        )
        self.retrieve_results = async_to_streamed_response_wrapper(
            evaluation_runs.retrieve_results,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Annotated, TypedDict

from ...._utils import PropertyInfo

__all__ = ["WorkspaceUpdateParams"]


class WorkspaceUpdateParams(TypedDict, total=False):
    description: str

    name: str

    body_workspace_uuid: Annotated[str, PropertyInfo(alias="workspace_uuid")]
    """Workspace UUID."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List

import httpx

from .agents import (
    AgentsResource,
    AsyncAgentsResource,
    AgentsResourceWithRawResponse,
    AsyncAgentsResourceWithRawResponse,
    AgentsResourceWithStreamingResponse,
    AsyncAgentsResourceWithStreamingResponse,
)
from ....._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from ....._utils import maybe_transform, async_maybe_transform
from ....._compat import cached_property
from ....._resource import SyncAPIResource, AsyncAPIResource
from ....._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ....._base_client import make_request_options
from .....types.agents.evaluation_metrics import workspace_create_params, workspace_update_params
from .....types.agents.evaluation_metrics.workspace_list_response import WorkspaceListResponse
from .....types.agents.evaluation_metrics.workspace_create_response import WorkspaceCreateResponse
from .....types.agents.evaluation_metrics.workspace_delete_response import WorkspaceDeleteResponse
from .....types.agents.evaluation_metrics.workspace_update_response import WorkspaceUpdateResponse
from .....types.agents.evaluation_metrics.workspace_retrieve_response import WorkspaceRetrieveResponse
from .....types.agents.evaluation_metrics.workspace_list_evaluation_test_cases_response import (
    WorkspaceListEvaluationTestCasesResponse,
)

__all__ = ["WorkspacesResource", "AsyncWorkspacesResource"]


class WorkspacesResource(SyncAPIResource):
    @cached_property
    def agents(self) -> AgentsResource:
        return AgentsResource(self._client)

    @cached_property
    def with_raw_response(self) -> WorkspacesResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/digitalocean/gradientai-python#accessing-raw-response-data-eg-headers
        """
        return WorkspacesResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> WorkspacesResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/digitalocean/gradientai-python#with_streaming_response
        """
        return WorkspacesResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        agent_uuids: List[str] | NotGiven = NOT_GIVEN,
        description: str | NotGiven = NOT_GIVEN,
        name: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> WorkspaceCreateResponse:
        """To create a new workspace, send a POST request to `/v2/gen-ai/workspaces`.

        The
        response body contains a JSON object with the newly created workspace object.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/v2/gen-ai/workspaces"
            if self._client._base_url_overridden
            else "https://api.digitalocean.com/v2/gen-ai/workspaces",
            body=maybe_transform(
                {
                    "agent_uuids": agent_uuids,
                    "description": description,
                    "name": name,
                },
                workspace_create_params.WorkspaceCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=WorkspaceCreateResponse,
        )

    def retrieve(
        self,
        workspace_uuid: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> WorkspaceRetrieveResponse:
        """
        To retrieve details of a workspace, GET request to
        `/v2/gen-ai/workspaces/{workspace_uuid}`. The response body is a JSON object
        containing the workspace.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not workspace_uuid:
            raise ValueError(f"Expected a non-empty value for `workspace_uuid` but received {workspace_uuid!r}")
        return self._get(
            f"/v2/gen-ai/workspaces/{workspace_uuid}"
            if self._client._base_url_overridden
            else f"https://api.digitalocean.com/v2/gen-ai/workspaces/{workspace_uuid}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=WorkspaceRetrieveResponse,
        )

    def update(
        self,
        path_workspace_uuid: str,
        *,
        description: str | NotGiven = NOT_GIVEN,
        name: str | NotGiven = NOT_GIVEN,
        body_workspace_uuid: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> WorkspaceUpdateResponse:
        """
        To update a workspace, send a PUT request to
        `/v2/gen-ai/workspaces/{workspace_uuid}`. The response body is a JSON object
        containing the workspace.

        Args:
          body_workspace_uuid: Workspace UUID.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not path_workspace_uuid:
            raise ValueError(
                f"Expected a non-empty value for `path_workspace_uuid` but received {path_workspace_uuid!r}"
            )
        return self._put(
            f"/v2/gen-ai/workspaces/{path_workspace_uuid}"
            if self._client._base_url_overridden
            else f"https://api.digitalocean.com/v2/gen-ai/workspaces/{path_workspace_uuid}",
            body=maybe_transform(
                {
                    "description": description,
                    "name": name,
                    "body_workspace_uuid": body_workspace_uuid,
                },
                workspace_update_params.WorkspaceUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=WorkspaceUpdateResponse,
        )

    def list(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> WorkspaceListResponse:
        """To list all workspaces, send a GET request to `/v2/gen-ai/workspaces`."""
        return self._get(
            "/v2/gen-ai/workspaces"
            if self._client._base_url_overridden
            else "https://api.digitalocean.com/v2/gen-ai/workspaces",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=WorkspaceListResponse,
        )

    def delete(
        self,
        workspace_uuid: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> WorkspaceDeleteResponse:
        """
        To delete a workspace, send a DELETE request to
        `/v2/gen-ai/workspace/{workspace_uuid}`.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not workspace_uuid:
            raise ValueError(f"Expected a non-empty value for `workspace_uuid` but received {workspace_uuid!r}")
        return self._delete(
            f"/v2/gen-ai/workspaces/{workspace_uuid}"
            if self._client._base_url_overridden
            else f"https://api.digitalocean.com/v2/gen-ai/workspaces/{workspace_uuid}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=WorkspaceDeleteResponse,
        )

    def list_evaluation_test_cases(
        self,
        workspace_uuid: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> WorkspaceListEvaluationTestCasesResponse:
        """
        To list all evaluation test cases by a workspace, send a GET request to
        `/v2/gen-ai/workspaces/{workspace_uuid}/evaluation_test_cases`.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not workspace_uuid:
            raise ValueError(f"Expected a non-empty value for `workspace_uuid` but received {workspace_uuid!r}")
        return self._get(
            f"/v2/gen-ai/workspaces/{workspace_uuid}/evaluation_test_cases"
            if self._client._base_url_overridden
            else f"https://api.digitalocean.com/v2/gen-ai/workspaces/{workspace_uuid}/evaluation_test_cases",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=WorkspaceListEvaluationTestCasesResponse,
        )


class AsyncWorkspacesResource(AsyncAPIResource):
    @cached_property
    def agents(self) -> AsyncAgentsResource:
        return AsyncAgentsResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncWorkspacesResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/digitalocean/gradientai-python#accessing-raw-response-data-eg-headers
        """
        return AsyncWorkspacesResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncWorkspacesResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/digitalocean/gradientai-python#with_streaming_response
        """
        return AsyncWorkspacesResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        agent_uuids: List[str] | NotGiven = NOT_GIVEN,
        description: str | NotGiven = NOT_GIVEN,
        name: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> WorkspaceCreateResponse:
        """To create a new workspace, send a POST request to `/v2/gen-ai/workspaces`.

        The
        response body contains a JSON object with the newly created workspace object.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/v2/gen-ai/workspaces"
            if self._client._base_url_overridden
            else "https://api.digitalocean.com/v2/gen-ai/workspaces",
            body=await async_maybe_transform(
                {
                    "agent_uuids": agent_uuids,
                    "description": description,
                    "name": name,
                },
                workspace_create_params.WorkspaceCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=WorkspaceCreateResponse,
        )

    async def retrieve(
        self,
        workspace_uuid: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> WorkspaceRetrieveResponse:
        """
        To retrieve details of a workspace, GET request to
        `/v2/gen-ai/workspaces/{workspace_uuid}`. The response body is a JSON object
        containing the workspace.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not workspace_uuid:
            raise ValueError(f"Expected a non-empty value for `workspace_uuid` but received {workspace_uuid!r}")
        return await self._get(
            f"/v2/gen-ai/workspaces/{workspace_uuid}"
            if self._client._base_url_overridden
            else f"https://api.digitalocean.com/v2/gen-ai/workspaces/{workspace_uuid}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=WorkspaceRetrieveResponse,
        )

    async def update(
        self,
        path_workspace_uuid: str,
        *,
        description: str | NotGiven = NOT_GIVEN,
        name: str | NotGiven = NOT_GIVEN,
        body_workspace_uuid: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> WorkspaceUpdateResponse:
        """
        To update a workspace, send a PUT request to
        `/v2/gen-ai/workspaces/{workspace_uuid}`. The response body is a JSON object
        containing the workspace.

        Args:
          body_workspace_uuid: Workspace UUID.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not path_workspace_uuid:
            raise ValueError(
                f"Expected a non-empty value for `path_workspace_uuid` but received {path_workspace_uuid!r}"
            )
        return await self._put(
            f"/v2/gen-ai/workspaces/{path_workspace_uuid}"
            if self._client._base_url_overridden
            else f"https://api.digitalocean.com/v2/gen-ai/workspaces/{path_workspace_uuid}",
            body=await async_maybe_transform(
                {
                    "description": description,
                    "name": name,
                    "body_workspace_uuid": body_workspace_uuid,
                },
                workspace_update_params.WorkspaceUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=WorkspaceUpdateResponse,
        )

    async def list(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> WorkspaceListResponse:
        """To list all workspaces, send a GET request to `/v2/gen-ai/workspaces`."""
        return await self._get(
            "/v2/gen-ai/workspaces"
            if self._client._base_url_overridden
            else "https://api.digitalocean.com/v2/gen-ai/workspaces",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=WorkspaceListResponse,
        )

    async def delete(
        self,
        workspace_uuid: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> WorkspaceDeleteResponse:
        """
        To delete a workspace, send a DELETE request to
        `/v2/gen-ai/workspace/{workspace_uuid}`.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not workspace_uuid:
            raise ValueError(f"Expected a non-empty value for `workspace_uuid` but received {workspace_uuid!r}")
        return await self._delete(
            f"/v2/gen-ai/workspaces/{workspace_uuid}"
            if self._client._base_url_overridden
            else f"https://api.digitalocean.com/v2/gen-ai/workspaces/{workspace_uuid}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=WorkspaceDeleteResponse,
        )

    async def list_evaluation_test_cases(
        self,
        workspace_uuid: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> WorkspaceListEvaluationTestCasesResponse:
        """
        To list all evaluation test cases by a workspace, send a GET request to
        `/v2/gen-ai/workspaces/{workspace_uuid}/evaluation_test_cases`.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not workspace_uuid:
            raise ValueError(f"Expected a non-empty value for `workspace_uuid` but received {workspace_uuid!r}")
        return await self._get(
            f"/v2/gen-ai/workspaces/{workspace_uuid}/evaluation_test_cases"
            if self._client._base_url_overridden
            else f"https://api.digitalocean.com/v2/gen-ai/workspaces/{workspace_uuid}/evaluation_test_cases",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=WorkspaceListEvaluationTestCasesResponse,
        )


class WorkspacesResourceWithRawResponse:
    def __init__(self, workspaces: WorkspacesResource) -> None:
        self._workspaces = workspaces

        self.create = to_raw_response_wrapper(
            workspaces.create,
        )
        self.retrieve = to_raw_response_wrapper(
            workspaces.retrieve,
        )
        self.update = to_raw_response_wrapper(
            workspaces.update,
        )
        self.list = to_raw_response_wrapper(
            workspaces.list,
        )
        self.delete = to_raw_response_wrapper(
            workspaces.delete,
        )
        self.list_evaluation_test_cases = to_raw_response_wrapper(
            workspaces.list_evaluation_test_cases,
        )

    @cached_property
    def agents(self) -> AgentsResourceWithRawResponse:
        return AgentsResourceWithRawResponse(self._workspaces.agents)


class AsyncWorkspacesResourceWithRawResponse:
    def __init__(self, workspaces: AsyncWorkspacesResource) -> None:
        self._workspaces = workspaces

        self.create = async_to_raw_response_wrapper(
            workspaces.create,
        )
        self.retrieve = async_to_raw_response_wrapper(
            workspaces.retrieve,
        )
        self.update = async_to_raw_response_wrapper(
            workspaces.update,
        )
        self.list = async_to_raw_response_wrapper(
            workspaces.list,
        )
        self.delete = async_to_raw_response_wrapper(
            workspaces.delete,
        )
        self.list_evaluation_test_cases = async_to_raw_response_wrapper(
            workspaces.list_evaluation_test_cases,
        )

    @cached_property
    def agents(self) -> AsyncAgentsResourceWithRawResponse:
        return AsyncAgentsResourceWithRawResponse(self._workspaces.agents)


class WorkspacesResourceWithStreamingResponse:
    def __init__(self, workspaces: WorkspacesResource) -> None:
        self._workspaces = workspaces

        self.create = to_streamed_response_wrapper(
            workspaces.create,
        )
        self.retrieve = to_streamed_response_wrapper(
            workspaces.retrieve,
        )
        self.update = to_streamed_response_wrapper(
            workspaces.update,
        )
        self.list = to_streamed_response_wrapper(
            workspaces.list,
        )
        self.delete = to_streamed_response_wrapper(
            workspaces.delete,
        )
        self.list_evaluation_test_cases = to_streamed_response_wrapper(
            workspaces.list_evaluation_test_cases,
        )

    @cached_property
    def agents(self) -> AgentsResourceWithStreamingResponse:
        return AgentsResourceWithStreamingResponse(self._workspaces.agents)


class AsyncWorkspacesResourceWithStreamingResponse:
    def __init__(self, workspaces: AsyncWorkspacesResource) -> None:
        self._workspaces = workspaces

        self.create = async_to_streamed_response_wrapper(
            workspaces.create,
        )
        self.retrieve = async_to_streamed_response_wrapper(
            workspaces.retrieve,
        )
        self.update = async_to_streamed_response_wrapper(
            workspaces.update,
        )
        self.list = async_to_streamed_response_wrapper(
            workspaces.list,
        )
        self.delete = async_to_streamed_response_wrapper(
            workspaces.delete,
        )
        self.list_evaluation_test_cases = async_to_streamed_response_wrapper(
            workspaces.list_evaluation_test_cases,
        )

    @cached_property
    def agents(self) -> AsyncAgentsResourceWithStreamingResponse:
        return AsyncAgentsResourceWithStreamingResponse(self._workspaces.agents)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from ..._models import BaseModel
from .api_evaluation_run import APIEvaluationRun

__all__ = ["EvaluationTestCaseListEvaluationRunsResponse"]


class EvaluationTestCaseListEvaluationRunsResponse(BaseModel):
    evaluation_runs: Optional[List[APIEvaluationRun]] = None
    """List of evaluation runs."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from ..._models import BaseModel
from ..shared.api_meta import APIMeta
from .api_indexing_job import APIIndexingJob
from ..shared.api_links import APILinks

__all__ = ["IndexingJobListResponse"]


class IndexingJobListResponse(BaseModel):
    jobs: Optional[List[APIIndexingJob]] = None

    links: Optional[APILinks] = None

    meta: Optional[APIMeta] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .model import Model as Model
from .shared import APIMeta as APIMeta, APILinks as APILinks
from .api_agent import APIAgent as APIAgent
from .api_agreement import APIAgreement as APIAgreement
from .api_workspace import APIWorkspace as APIWorkspace
from .api_agent_model import APIAgentModel as APIAgentModel
from .agent_list_params import AgentListParams as AgentListParams
from .api_model_version import APIModelVersion as APIModelVersion
from .api_knowledge_base import APIKnowledgeBase as APIKnowledgeBase
from .region_list_params import RegionListParams as RegionListParams
from .agent_create_params import AgentCreateParams as AgentCreateParams
from .agent_list_response import AgentListResponse as AgentListResponse
from .agent_update_params import AgentUpdateParams as AgentUpdateParams
from .model_list_response import ModelListResponse as ModelListResponse
from .api_retrieval_method import APIRetrievalMethod as APIRetrievalMethod
from .region_list_response import RegionListResponse as RegionListResponse
from .agent_create_response import AgentCreateResponse as AgentCreateResponse
from .agent_delete_response import AgentDeleteResponse as AgentDeleteResponse
from .agent_update_response import AgentUpdateResponse as AgentUpdateResponse
from .api_agent_api_key_info import APIAgentAPIKeyInfo as APIAgentAPIKeyInfo
from .agent_retrieve_response import AgentRetrieveResponse as AgentRetrieveResponse
from .api_openai_api_key_info import APIOpenAIAPIKeyInfo as APIOpenAIAPIKeyInfo
from .api_deployment_visibility import APIDeploymentVisibility as APIDeploymentVisibility
from .agent_update_status_params import AgentUpdateStatusParams as AgentUpdateStatusParams
from .api_anthropic_api_key_info import APIAnthropicAPIKeyInfo as APIAnthropicAPIKeyInfo
from .knowledge_base_list_params import KnowledgeBaseListParams as KnowledgeBaseListParams
from .agent_update_status_response import AgentUpdateStatusResponse as AgentUpdateStatusResponse
from .knowledge_base_create_params import KnowledgeBaseCreateParams as KnowledgeBaseCreateParams
from .knowledge_base_list_response import KnowledgeBaseListResponse as KnowledgeBaseListResponse
from .knowledge_base_update_params import KnowledgeBaseUpdateParams as KnowledgeBaseUpdateParams
from .knowledge_base_create_response import KnowledgeBaseCreateResponse as KnowledgeBaseCreateResponse
from .knowledge_base_delete_response import KnowledgeBaseDeleteResponse as KnowledgeBaseDeleteResponse
from .knowledge_base_update_response import KnowledgeBaseUpdateResponse as KnowledgeBaseUpdateResponse
from .knowledge_base_retrieve_response import KnowledgeBaseRetrieveResponse as KnowledgeBaseRetrieveResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Annotated, TypedDict

from ...._utils import PropertyInfo

__all__ = ["KeyUpdateParams"]


class KeyUpdateParams(TypedDict, total=False):
    api_key: str

    body_api_key_uuid: Annotated[str, PropertyInfo(alias="api_key_uuid")]

    name: str



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from gradientai import GradientAI, AsyncGradientAI
from tests.utils import assert_matches_type
from gradientai.types.model_providers.anthropic import (
    KeyListResponse,
    KeyCreateResponse,
    KeyDeleteResponse,
    KeyUpdateResponse,
    KeyRetrieveResponse,
    KeyListAgentsResponse,
)

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestKeys:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip()
    @parametrize
    def test_method_create(self, client: GradientAI) -> None:
        key = client.model_providers.anthropic.keys.create()
        assert_matches_type(KeyCreateResponse, key, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_method_create_with_all_params(self, client: GradientAI) -> None:
        key = client.model_providers.anthropic.keys.create(
            api_key="api_key",
            name="name",
        )
        assert_matches_type(KeyCreateResponse, key, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_create(self, client: GradientAI) -> None:
        response = client.model_providers.anthropic.keys.with_raw_response.create()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        key = response.parse()
        assert_matches_type(KeyCreateResponse, key, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_create(self, client: GradientAI) -> None:
        with client.model_providers.anthropic.keys.with_streaming_response.create() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            key = response.parse()
            assert_matches_type(KeyCreateResponse, key, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_method_retrieve(self, client: GradientAI) -> None:
        key = client.model_providers.anthropic.keys.retrieve(
            "api_key_uuid",
        )
        assert_matches_type(KeyRetrieveResponse, key, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_retrieve(self, client: GradientAI) -> None:
        response = client.model_providers.anthropic.keys.with_raw_response.retrieve(
            "api_key_uuid",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        key = response.parse()
        assert_matches_type(KeyRetrieveResponse, key, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_retrieve(self, client: GradientAI) -> None:
        with client.model_providers.anthropic.keys.with_streaming_response.retrieve(
            "api_key_uuid",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            key = response.parse()
            assert_matches_type(KeyRetrieveResponse, key, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_path_params_retrieve(self, client: GradientAI) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `api_key_uuid` but received ''"):
            client.model_providers.anthropic.keys.with_raw_response.retrieve(
                "",
            )

    @pytest.mark.skip()
    @parametrize
    def test_method_update(self, client: GradientAI) -> None:
        key = client.model_providers.anthropic.keys.update(
            path_api_key_uuid="api_key_uuid",
        )
        assert_matches_type(KeyUpdateResponse, key, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_method_update_with_all_params(self, client: GradientAI) -> None:
        key = client.model_providers.anthropic.keys.update(
            path_api_key_uuid="api_key_uuid",
            api_key="api_key",
            body_api_key_uuid="api_key_uuid",
            name="name",
        )
        assert_matches_type(KeyUpdateResponse, key, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_update(self, client: GradientAI) -> None:
        response = client.model_providers.anthropic.keys.with_raw_response.update(
            path_api_key_uuid="api_key_uuid",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        key = response.parse()
        assert_matches_type(KeyUpdateResponse, key, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_update(self, client: GradientAI) -> None:
        with client.model_providers.anthropic.keys.with_streaming_response.update(
            path_api_key_uuid="api_key_uuid",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            key = response.parse()
            assert_matches_type(KeyUpdateResponse, key, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_path_params_update(self, client: GradientAI) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `path_api_key_uuid` but received ''"):
            client.model_providers.anthropic.keys.with_raw_response.update(
                path_api_key_uuid="",
            )

    @pytest.mark.skip()
    @parametrize
    def test_method_list(self, client: GradientAI) -> None:
        key = client.model_providers.anthropic.keys.list()
        assert_matches_type(KeyListResponse, key, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_method_list_with_all_params(self, client: GradientAI) -> None:
        key = client.model_providers.anthropic.keys.list(
            page=0,
            per_page=0,
        )
        assert_matches_type(KeyListResponse, key, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_list(self, client: GradientAI) -> None:
        response = client.model_providers.anthropic.keys.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        key = response.parse()
        assert_matches_type(KeyListResponse, key, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_list(self, client: GradientAI) -> None:
        with client.model_providers.anthropic.keys.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            key = response.parse()
            assert_matches_type(KeyListResponse, key, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_method_delete(self, client: GradientAI) -> None:
        key = client.model_providers.anthropic.keys.delete(
            "api_key_uuid",
        )
        assert_matches_type(KeyDeleteResponse, key, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_delete(self, client: GradientAI) -> None:
        response = client.model_providers.anthropic.keys.with_raw_response.delete(
            "api_key_uuid",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        key = response.parse()
        assert_matches_type(KeyDeleteResponse, key, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_delete(self, client: GradientAI) -> None:
        with client.model_providers.anthropic.keys.with_streaming_response.delete(
            "api_key_uuid",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            key = response.parse()
            assert_matches_type(KeyDeleteResponse, key, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_path_params_delete(self, client: GradientAI) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `api_key_uuid` but received ''"):
            client.model_providers.anthropic.keys.with_raw_response.delete(
                "",
            )

    @pytest.mark.skip()
    @parametrize
    def test_method_list_agents(self, client: GradientAI) -> None:
        key = client.model_providers.anthropic.keys.list_agents(
            uuid="uuid",
        )
        assert_matches_type(KeyListAgentsResponse, key, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_method_list_agents_with_all_params(self, client: GradientAI) -> None:
        key = client.model_providers.anthropic.keys.list_agents(
            uuid="uuid",
            page=0,
            per_page=0,
        )
        assert_matches_type(KeyListAgentsResponse, key, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_list_agents(self, client: GradientAI) -> None:
        response = client.model_providers.anthropic.keys.with_raw_response.list_agents(
            uuid="uuid",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        key = response.parse()
        assert_matches_type(KeyListAgentsResponse, key, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_list_agents(self, client: GradientAI) -> None:
        with client.model_providers.anthropic.keys.with_streaming_response.list_agents(
            uuid="uuid",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            key = response.parse()
            assert_matches_type(KeyListAgentsResponse, key, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_path_params_list_agents(self, client: GradientAI) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `uuid` but received ''"):
            client.model_providers.anthropic.keys.with_raw_response.list_agents(
                uuid="",
            )


class TestAsyncKeys:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip()
    @parametrize
    async def test_method_create(self, async_client: AsyncGradientAI) -> None:
        key = await async_client.model_providers.anthropic.keys.create()
        assert_matches_type(KeyCreateResponse, key, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_create_with_all_params(self, async_client: AsyncGradientAI) -> None:
        key = await async_client.model_providers.anthropic.keys.create(
            api_key="api_key",
            name="name",
        )
        assert_matches_type(KeyCreateResponse, key, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_create(self, async_client: AsyncGradientAI) -> None:
        response = await async_client.model_providers.anthropic.keys.with_raw_response.create()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        key = await response.parse()
        assert_matches_type(KeyCreateResponse, key, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_create(self, async_client: AsyncGradientAI) -> None:
        async with async_client.model_providers.anthropic.keys.with_streaming_response.create() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            key = await response.parse()
            assert_matches_type(KeyCreateResponse, key, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_method_retrieve(self, async_client: AsyncGradientAI) -> None:
        key = await async_client.model_providers.anthropic.keys.retrieve(
            "api_key_uuid",
        )
        assert_matches_type(KeyRetrieveResponse, key, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_retrieve(self, async_client: AsyncGradientAI) -> None:
        response = await async_client.model_providers.anthropic.keys.with_raw_response.retrieve(
            "api_key_uuid",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        key = await response.parse()
        assert_matches_type(KeyRetrieveResponse, key, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_retrieve(self, async_client: AsyncGradientAI) -> None:
        async with async_client.model_providers.anthropic.keys.with_streaming_response.retrieve(
            "api_key_uuid",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            key = await response.parse()
            assert_matches_type(KeyRetrieveResponse, key, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_path_params_retrieve(self, async_client: AsyncGradientAI) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `api_key_uuid` but received ''"):
            await async_client.model_providers.anthropic.keys.with_raw_response.retrieve(
                "",
            )

    @pytest.mark.skip()
    @parametrize
    async def test_method_update(self, async_client: AsyncGradientAI) -> None:
        key = await async_client.model_providers.anthropic.keys.update(
            path_api_key_uuid="api_key_uuid",
        )
        assert_matches_type(KeyUpdateResponse, key, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_update_with_all_params(self, async_client: AsyncGradientAI) -> None:
        key = await async_client.model_providers.anthropic.keys.update(
            path_api_key_uuid="api_key_uuid",
            api_key="api_key",
            body_api_key_uuid="api_key_uuid",
            name="name",
        )
        assert_matches_type(KeyUpdateResponse, key, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_update(self, async_client: AsyncGradientAI) -> None:
        response = await async_client.model_providers.anthropic.keys.with_raw_response.update(
            path_api_key_uuid="api_key_uuid",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        key = await response.parse()
        assert_matches_type(KeyUpdateResponse, key, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_update(self, async_client: AsyncGradientAI) -> None:
        async with async_client.model_providers.anthropic.keys.with_streaming_response.update(
            path_api_key_uuid="api_key_uuid",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            key = await response.parse()
            assert_matches_type(KeyUpdateResponse, key, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_path_params_update(self, async_client: AsyncGradientAI) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `path_api_key_uuid` but received ''"):
            await async_client.model_providers.anthropic.keys.with_raw_response.update(
                path_api_key_uuid="",
            )

    @pytest.mark.skip()
    @parametrize
    async def test_method_list(self, async_client: AsyncGradientAI) -> None:
        key = await async_client.model_providers.anthropic.keys.list()
        assert_matches_type(KeyListResponse, key, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_list_with_all_params(self, async_client: AsyncGradientAI) -> None:
        key = await async_client.model_providers.anthropic.keys.list(
            page=0,
            per_page=0,
        )
        assert_matches_type(KeyListResponse, key, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_list(self, async_client: AsyncGradientAI) -> None:
        response = await async_client.model_providers.anthropic.keys.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        key = await response.parse()
        assert_matches_type(KeyListResponse, key, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_list(self, async_client: AsyncGradientAI) -> None:
        async with async_client.model_providers.anthropic.keys.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            key = await response.parse()
            assert_matches_type(KeyListResponse, key, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_method_delete(self, async_client: AsyncGradientAI) -> None:
        key = await async_client.model_providers.anthropic.keys.delete(
            "api_key_uuid",
        )
        assert_matches_type(KeyDeleteResponse, key, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_delete(self, async_client: AsyncGradientAI) -> None:
        response = await async_client.model_providers.anthropic.keys.with_raw_response.delete(
            "api_key_uuid",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        key = await response.parse()
        assert_matches_type(KeyDeleteResponse, key, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_delete(self, async_client: AsyncGradientAI) -> None:
        async with async_client.model_providers.anthropic.keys.with_streaming_response.delete(
            "api_key_uuid",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            key = await response.parse()
            assert_matches_type(KeyDeleteResponse, key, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_path_params_delete(self, async_client: AsyncGradientAI) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `api_key_uuid` but received ''"):
            await async_client.model_providers.anthropic.keys.with_raw_response.delete(
                "",
            )

    @pytest.mark.skip()
    @parametrize
    async def test_method_list_agents(self, async_client: AsyncGradientAI) -> None:
        key = await async_client.model_providers.anthropic.keys.list_agents(
            uuid="uuid",
        )
        assert_matches_type(KeyListAgentsResponse, key, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_list_agents_with_all_params(self, async_client: AsyncGradientAI) -> None:
        key = await async_client.model_providers.anthropic.keys.list_agents(
            uuid="uuid",
            page=0,
            per_page=0,
        )
        assert_matches_type(KeyListAgentsResponse, key, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_list_agents(self, async_client: AsyncGradientAI) -> None:
        response = await async_client.model_providers.anthropic.keys.with_raw_response.list_agents(
            uuid="uuid",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        key = await response.parse()
        assert_matches_type(KeyListAgentsResponse, key, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_list_agents(self, async_client: AsyncGradientAI) -> None:
        async with async_client.model_providers.anthropic.keys.with_streaming_response.list_agents(
            uuid="uuid",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            key = await response.parse()
            assert_matches_type(KeyListAgentsResponse, key, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_path_params_list_agents(self, async_client: AsyncGradientAI) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `uuid` but received ''"):
            await async_client.model_providers.anthropic.keys.with_raw_response.list_agents(
                uuid="",
            )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from ..._models import BaseModel
from .api_knowledge_base_data_source import APIKnowledgeBaseDataSource

__all__ = ["DataSourceCreateResponse"]


class DataSourceCreateResponse(BaseModel):
    knowledge_base_data_source: Optional[APIKnowledgeBaseDataSource] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from .._models import BaseModel

__all__ = ["RegionListResponse", "Region"]


class Region(BaseModel):
    inference_url: Optional[str] = None

    region: Optional[str] = None

    serves_batch: Optional[bool] = None

    serves_inference: Optional[bool] = None

    stream_inference_url: Optional[str] = None


class RegionListResponse(BaseModel):
    regions: Optional[List[Region]] = None
